@@ -5,10 +5,10 @@ use Moo 1.003 ();
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '2.03';
+our $VERSION = '5.00';
 
 my %Default_Plugins = (
-    client      => [ 'Search::Elasticsearch::Client',       '2_0::Direct' ],
+    client      => [ 'Search::Elasticsearch::Client',       '5_0::Direct' ],
     cxn_factory => [ 'Search::Elasticsearch::Cxn::Factory', '' ],
     cxn_pool    => [ 'Search::Elasticsearch::CxnPool',      'Static' ],
     logger      => [ 'Search::Elasticsearch::Logger',       'LogAny' ],
@@ -62,7 +62,7 @@ Search::Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -139,11 +139,29 @@ itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
 on L<elastic.co|http://www.elastic.co>.
 
-=head1 BACKWARDS COMPATIBILITY
+=head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 2.0 branch by
-default, see L</Client> section below for details of working with 1.0
-and 0.90 branches.
+This version of the client supports the Elasticsearch 5.0 branch,
+which is not backwards compatible with earlier branches.
+
+If you need to talk to a version of Elasticsearch before 5.0.0, please
+install one of the following packages:
+
+=over
+
+=item *
+
+L<Search::Elasticsearch::Client::2_0>
+
+=item *
+
+L<Search::Elasticsearch::Client::1_0>
+
+=item *
+
+L<Search::Elasticsearch::Client::0_90>
+
+=back
 
 =head2 Motivation
 
@@ -194,9 +212,8 @@ Good defaults
 =item *
 
 Helper utilities for more complex operations, such as
-L<bulk indexing|Search::Elasticsearch::Bulk>,
-L<scrolled searches|Search::Elasticsearch::Scroll> and
-L<reindexing|Search::Elasticsearch::Bulk/"reindex()">.
+L<bulk indexing|Search::Elasticsearch::Client::5_0::Bulk>, and
+L<scrolled searches|Search::Elasticsearch::Client::5_0::Scroll>
 
 =item *
 
@@ -204,7 +221,7 @@ Logging support via L<Log::Any>
 
 =item *
 
-Compatibility with the official clients for Python, Ruby, PHP and Javascript
+Compatibility with the official clients for Python, Ruby, PHP, and Javascript
 
 =item *
 
@@ -216,13 +233,13 @@ Easy extensibility
 
 You can download the latest version of Elasticsearch from
 L<http://www.elastic.co/download>. See the
-L<installation instructions|http://www.elastic.co/guide/reference/setup/installation/>
+L<installation instructions|https://www.elastic.co/guide/en/elasticsearch/reference/current/setup.html>
 for details. You will need to have a recent version of Java installed,
-preferably the Java v7 from Sun.
+preferably the Java v8 from Sun.
 
 =head1 CREATING A NEW INSTANCE
 
-The L</new()> method returns a new L<client|Search::Elasticsearch::Client::2_0::Direct>
+The L</new()> method returns a new L<client|Search::Elasticsearch::Client::5_0::Direct>
 which can be used to run requests against the Elasticsearch cluster.
 
     use Search::Elasticsearch;
@@ -255,7 +272,7 @@ Each C<node> can be a URL including a scheme, host, port, path and userinfo
 
     https://username:password@search.domain.com:443/prefix/path
 
-See L<Search::Elasticsearch::Role::Cxn::HTTP/node> for more on node specification.
+See L<Search::Elasticsearch::Role::Cxn/node> for more on node specification.
 
 =head2 C<cxn_pool>
 
@@ -342,7 +359,7 @@ Other arguments are explained in the respective L<module docs|/MODULES>.
 =head1 RUNNING REQUESTS
 
 When you create a new instance of Search::Elasticsearch, it returns a
-L<client|Search::Elasticsearch::Client::2_0::Direct> object, which can be used for
+L<client|Search::Elasticsearch::Client::5_0::Direct> object, which can be used for
 running requests.
 
     use Search::Elasticsearch;
@@ -363,7 +380,7 @@ running requests.
         }
     );
 
-See L<Search::Elasticsearch::Client::2_0::Direct> for more details about the requests that
+See L<Search::Elasticsearch::Client::5_0::Direct> for more details about the requests that
 can be run.
 
 =head1 MODULES
@@ -395,28 +412,13 @@ methods that can be called to execute requests, such as
 C<search()>, C<index()> or C<delete()>. The client parses the user's
 requests and passes them to the L</transport> class to be executed.
 
-The default version of the client is C<2_0::Direct>, which can
+The default version of the client is C<5_0::Direct>, which can
 be explicitly specified as follows:
 
     $e = Search::Elasticsearch->new(
-        client => '2_0::Direct'
+        client => '5_0::Direct'
     );
 
-See :
-
-=over
-
-=item * L<Search::Elasticsearch::Client::2_0::Direct> (default, for 2.0 branch)
-
-=item * L<Search::Elasticsearch::Client::1_0::Direct> (for 1.0 branch)
-
-=item * L<Search::Elasticsearch::Client::0_90::Direct> (for 0.90 branch)
-
-=item * L<Search::Elasticsearch::Client::Compat> (for migration from the old
-L<ElasticSearch> module)
-
-=back
-
 =head2 C<transport>
 
 The Transport class accepts a parsed request from the L</client> class,
@@ -500,93 +502,6 @@ bodies.  See:
 
 =back
 
-=head1 MIGRATING FROM ElasticSearch.pm
-
-See L<Search::Elasticsearch::Compat>, which allows you to run your old
-L<ElasticSearch> code with the new L<Search::Elasticsearch> module.
-
-The L<Search::Elasticsearch> API is pretty similar to the old L<ElasticSearch>
-API, but there are a few differences.  The most notable are:
-
-=head2 C<hosts> vs C<servers>
-
-When instantiating a new Search::Elasticsearch instance, use C<nodes> instead
-of C<servers>:
-
-    $e = Search::Elasticsearch->new(
-        nodes => [ 'search1:9200', 'search2:9200' ]
-    );
-
-=head2 C<no_refresh>
-
-By default, the new client does not sniff the cluster to discover nodes.
-To enable sniffing, use:
-
-    $e = Search::Elasticsearch->new(
-        cxn_pool => 'Sniff',
-        nodes    => [ 'search1:9200', 'search2:9200' ]
-    );
-
-To disable sniffing (the equivalent of setting C<no_refresh> to C<true>), do:
-
-    $e = Search::Elasticsearch->new(
-        nodes    => [ 'search1:9200', 'search2:9200' ]
-    );
-
-=head2 Request parameters
-
-In the old client, you could specify query string and body parameters at
-the same level, eg:
-
-    $e->search(
-        search_type => 'count',
-        query       => {
-            match_all => {}
-        }
-    );
-
-In the new client, body parameters should be passed in a C<body> element:
-
-    $e->search(
-        search_type => 'count',
-        body        => {
-            query       => {
-                match_all => {}
-            }
-        }
-    );
-
-=head2 C<trace_calls>
-
-The new client uses L<Log::Any> for event logging and request tracing.
-To trace requests/responses in C<curl> format, do:
-
-    # To STDERR
-    $e = Search::Elasticsearch->new (trace_to => 'Stderr');
-
-    # To a file
-    $e = Search::Elasticsearch->new (trace_to => ['File','/path/to/file.log']);
-
-=head2 SearchBuilder
-
-The old API integrated L<ElasticSearch::SearchBuilder> for an L<SQL::Abstract>
-style of writing queries and filters in Elasticsearch.
-This integration does not exist in the new client.
-
-=head2 Bulk methods and C<scrolled_search()>
-
-Bulk indexing has changed a lot in the new client.  The helper methods, eg
-C<bulk_index()> and C<reindex()> have been removed from the main client,
-and the C<bulk()> method itself now simply returns the response from
-Elasticsearch. It doesn't interfere with processing at all.
-
-These helper methods have been replaced by the L<Search::Elasticsearch::Bulk>
-class. Similarly, C<scrolled_search()> has been replaced by the
-L<Search::Elasticsearch::Scroll>.  These helper classes are accessible as:
-
-    $bulk   = $e->bulk_helper( %args_to_new );
-    $scroll = $e->scroll_helper( %args_to_new );
-
 =head1 BUGS
 
 This is a stable API but this implementation is new. Watch this space
@@ -626,7 +541,7 @@ C<irc.freenode.net>.
 
 =item * Mailing list
 
-The main L<Elasticsearch mailing list|http://www.elastic.co/community>.
+The main L<Elasticsearch mailing list|http://discuss.elastic.co>.
 
 =back
 
