@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::1_0::Direct::Indices;
-$Search::Elasticsearch::Client::1_0::Direct::Indices::VERSION = '2.03';
+package Search::Elasticsearch::Client::5_0::Direct::Indices;
+$Search::Elasticsearch::Client::5_0::Direct::Indices::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Role::API::1_0';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('indices');
 
@@ -13,17 +13,17 @@ __PACKAGE__->_install_api('indices');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::1_0::Direct::Indices - A client for running index-level requests
+Search::Elasticsearch::Client::5_0::Direct::Indices - A client for running index-level requests
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
 This module provides methods to make index-level requests, such as
 creating and deleting indices, managing type mappings, index settings,
-warmers, index templates and aliases.
+index templates and aliases.
 
 It does L<Search::Elasticsearch::Role::Client::Direct>.
 
@@ -37,16 +37,18 @@ It does L<Search::Elasticsearch::Role::Client::Direct>.
         body  => {                      # optional
             index settings
             mappings
-            warmers
+            aliases
         }
     );
 
 The C<create()> method is used to create an index. Optionally, index
-settings, type mappings and index warmers can be added at the same time.
+settings, type mappings, and aliases can be added at the same time.
 
 Query string parameters:
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<update_all_types>,
+    C<wait_for_active_shards>
 
 See the L<create index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-create-index.html>
 for more information.
@@ -58,16 +60,18 @@ for more information.
         feature => 'feature' | \@features   # optional
     );
 
-Returns the aliases, settings, mappings, and warmers for the specified indices.
+Returns the aliases, settings, and mappingsfor the specified indices.
 The C<feature> parameter can be set to none or more of: C<_settings>, C<_mappings>,
-C<_warmers> and C<_aliases>.
+and C<_aliases>.
 
 See the L<get index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-index.html>.
 
 Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
+    C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 =head2 C<exists()>
@@ -143,6 +147,44 @@ Query string parameters:
 See the L<open index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-open-close.html>
 for more information.
 
+=head2 C<rollover()>
+
+    $response = $e->indices->rollover(
+        alias     => $alias,                    # required
+        new_index => $index,                    # optional
+        body      => { rollover conditions }    # optional
+    );
+
+Rollover an index pointed to by C<alias> if it meets rollover conditions
+(eg max age, max docs) to a new index name.
+
+Query string parameters:
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<rollover index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-rollover-index.html>
+for more information.
+
+=head2 C<shrink()>
+
+    $response = $e->shrink(
+        index  => $index,                           # required
+        target => $target,                          # required
+        body   => { mappings, settings aliases }    # optional
+    );
+
+The shrink API shrinks the shards of an index down to a single shard (or to a factor
+of the original shards).
+
+Query string parameters:
+    C<master_timeout>,
+    C<timeout>,
+    C<wait_for_active_shards>
+
+See the L<shrink index docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/indices-shrink-index.html>
+for more information.
+
 =head2 C<clear_cache()>
 
     $response = $e->indices->clear_cache(
@@ -157,14 +199,10 @@ Query string parameters:
     C<expand_wildcards>,
     C<fielddata>,
     C<fields>,
-    C<filter>,
-    C<filter_cache>,
-    C<filter_keys>,
-    C<id>,
-    C<id_cache>,
     C<ignore_unavailable>,
-    C<query_cache>,
-    C<recycler>
+    C<query>,
+    C<recycler>,
+    C<request>
 
 See the L<clear_cache docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-clearcache.html>
 for more information.
@@ -202,7 +240,6 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<force>,
-    C<full>,
     C<ignore_unavailable>,
     C<wait_if_ongoing>
 
@@ -226,16 +263,21 @@ Synced flushes happens automatically in the background on indices that have not
 writes for a while, but the L<flush_synced()> method can be used to trigger this process
 manually, eg before shutting down.  Any new commits immediately break the sync.
 
-See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/flush.html>
+See the L<flush synced docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-synced-flush.html>
 for more information.
 
-=head2 C<optimize()>
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<ignore_unavailable>
 
-    $response = $e->indices->optimize(
+=head2 C<forcemerge()>
+
+    $response = $e->indices->forcemerge(
         index => 'index' | \@indices    # optional
     );
 
-The C<optimize()> method rewrites all the data in an index into at most
+The C<forcemerge()> method rewrites all the data in an index into at most
 C<max_num_segments>.  This is a very heavy operation and should only be run
 with care, and only on indices that are no longer being updated.
 
@@ -248,7 +290,7 @@ Query string parameters:
     C<only_expunge_deletes>,
     C<wait_for_merge>
 
-See the L<optimize index docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-optimize.html>
+See the L<forcemerge docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-forcemerge.html>
 for more information.
 
 =head2 C<get_upgrade()>
@@ -321,9 +363,9 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<ignore_unavailable>,
-    C<ignore_conflicts>,
     C<master_timeout>,
-    C<timeout>
+    C<timeout>,
+    C<update_all_types>
 
 See the L<put_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-put-mapping.html>
 for more information.
@@ -350,9 +392,9 @@ for more information.
 =head2 C<get_field_mapping()>
 
     $result = $e->indices->get_field_mapping(
-        index => 'index' | \@indices    # optional,
-        type  => 'type'  | \@types      # optional,
-        field => 'field' | \@fields     # required
+        index => 'index'  | \@indices    # optional,
+        type  => 'type'   | \@types      # optional,
+        fields => 'field' | \@fields     # required
 
         include_defaults => 0 | 1
     );
@@ -389,22 +431,6 @@ Query string parameters:
 See the L<exists_type docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-types-exists.html>
 for more information.
 
-=head2 C<delete_mapping()>
-
-    $response = $e->indices->delete_mapping(
-        index => 'index' | \@indices    # required,
-        type  => 'type'  | \@types      # required
-    );
-
-The C<delete_mapping()> method deletes the type mappings (and all documents of
-that type) in all specified indices.
-
-Query string parameters:
-    C<master_timeout>
-
-See the L<delete_mapping docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-delete-mapping.html>
-for more information.
-
 =head1 ALIAS METHODS
 
 =head2 C<update_aliases()>
@@ -432,23 +458,6 @@ Query string parameters:
 See the L<update_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
 for more information.
 
-=head2 C<get_aliases()>
-
-    $result = $e->indices->get_aliases(
-        index   => 'index' | \@indices,     # optional
-        alias   => 'alias' | \@aliases      # optional
-    );
-
-The C<get_aliases()> method returns a list of aliases per index for all
-the specified indices.
-
-Query string parameters:
-    C<local>,
-    C<timeout>
-
-See the L<get_aliases docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-aliases.html>
-for more information.
-
 =head2 C<put_alias()>
 
     $response = $e->indices->put_alias(
@@ -554,7 +563,8 @@ Query string parameters:
     C<expand_wildcards>,
     C<flat_settings>,
     C<ignore_unavailable>,
-    C<master_timeout>
+    C<master_timeout>,
+    C<preserve_existing>
 
 See the L<put_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-update-settings.html>
 for more information.
@@ -573,7 +583,9 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<flat_settings>,
+    C<human>,
     C<ignore_unavailable>,
+    C<include_defaults>,
     C<local>
 
 See the L<get_settings docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-get-settings.html>
@@ -606,7 +618,7 @@ for more information.
 =head2 C<get_template()>
 
     $result = $e->indices->get_template(
-        name  => 'template'                 # optional
+        name  => 'template' | \@templates # optional
     );
 
 The C<get_template()> method is used to retrieve a named template.
@@ -651,73 +663,6 @@ Query string parameters:
 See the L<delete_template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-templates.html>
 for more information.
 
-=head1 WARMER METHODS
-
-=head2 C<put_warmer()>
-
-    $response = $e->indices->put_warmer(
-        index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
-        name    => 'warmer',                # required
-
-        body    => { warmer defn }          # required
-    );
-
-The C<put_warmer()> method is used to create or update named warmers which
-are used to I<warm up> new segments in the index before they are exposed
-to user searches.  For instance:
-
-    $response = $e->indices->put_warmer(
-        index   => 'my_index',
-        name    => 'date_field_warmer',
-        body    => {
-            sort => 'date'
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<master_timeout>
-
-See the L<put_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
-=head2 C<get_warmer()>
-
-    $response = $e->indices->get_warmer(
-        index   => 'index'  | \@indices,    # optional
-        type    => 'type'   | \@types,      # optional
-        name    => 'warmer' | \@warmers,    # optional
-    );
-
-The C<get_warmer()> method is used to retrieve warmers by name.
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<expand_wildcards>,
-    C<ignore_unavailable>,
-    C<local>
-
-See the L<get_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
-=head2 C<delete_warmer()>
-
-    $response = $e->indices->get_warmer(
-        index   => 'index'  | \@indices,    # required
-        name    => 'warmer' | \@warmers,    # required
-    );
-
-The C<delete_warmer()> method is used to delete warmers by name.
-
-Query string parameters:
-    C<master_timeout>
-
-See the L<delete_warmer docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-warmers.html>
-for more information.
-
 =head1 STATS METHODS
 
 =head2 C<stats()>
@@ -745,10 +690,10 @@ Allowed metrics are:
     C<percolate>,
     C<query_cache>,
     C<refresh>,
+    C<request_cache>,
     C<search>,
     C<segments>,
-    C<store>,
-    C<warmer>
+    C<store>
 
 Query string parameters:
     C<completion_fields>,
@@ -791,11 +736,31 @@ Query string parameters:
     C<allow_no_indices>,
     C<expand_wildcards>,
     C<human>,
-    C<ignore_unavailable>
+    C<ignore_unavailable>,
+    C<verbose>
 
 See the L<segments docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-segments.html>
 for more information.
 
+=head2 C<shard_stores()>
+
+    $result = $e->indices->shard_stores(
+        index   => 'index' | \@indices      # optional
+    );
+
+The C<shard_stores()> method is used to find out which nodes contain
+copies of which shards, whether the shards are allocated or not.
+
+Query string parameters:
+    C<allow_no_indices>,
+    C<expand_wildcards>,
+    C<human>,
+    C<ignore_unavailable>,
+    C<status>
+
+See the L<shard_stores docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-shards-stores.html>
+for more information.
+
 =head1 QUERY AND ANALYSIS METHODS
 
 =head2 C<analyze()>
@@ -812,12 +777,13 @@ for debugging analyzer configurations.
 
 Query string parameters:
     C<analyzer>,
-    C<char_filters>,
+    C<attributes>,
+    C<char_filter>,
+    C<explain>,
     C<field>,
-    C<filters>,
+    C<filter>,
     C<format>,
     C<prefer_local>,
-    C<rewrite>,
     C<text>,
     C<tokenizer>
 
@@ -843,12 +809,13 @@ Query string parameters:
     C<analyzer>,
     C<default_operator>,
     C<df>,
-    C<expand_wildcards>,
     C<explain>,
+    C<expand_wildcards>,
     C<ignore_unavailable>,
     C<lenient>,
-    C<lowercase_expanded_terms>,
-    C<q>
+    C<lowercase_expanded_terms>
+    C<q>,
+    C<rewrite>
 
 See the L<validate_query docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/indices-validate.html>
 for more information.
