@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::2_0::Direct::Nodes;
-$Search::Elasticsearch::Client::2_0::Direct::Nodes::VERSION = '2.03';
+package Search::Elasticsearch::Client::5_0::Direct::Nodes;
+$Search::Elasticsearch::Client::5_0::Direct::Nodes::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Role::API::2_0';
+with 'Search::Elasticsearch::Client::5_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('nodes');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('nodes');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::2_0::Direct::Nodes - A client for running node-level requests
+Search::Elasticsearch::Client::5_0::Direct::Nodes - A client for running node-level requests
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -89,7 +89,7 @@ Allowed metrics are:
     C<transport>
 
 If the C<indices> metric (or C<_all>) is specified, then
-L<indices_stats|Search::Elasticsearch::Client::2_0::Direct::Indices/indices_stats()>
+L<indices_stats|Search::Elasticsearch::Client::5_0::Direct::Indices/indices_stats()>
 information is returned on a per-node basis. Which indices stats are
 returned can be controlled with the C<index_metric> parameter:
 
