@@ -1,12 +1,12 @@
 package Search::Elasticsearch::Cxn::Factory;
-$Search::Elasticsearch::Cxn::Factory::VERSION = '2.03';
+$Search::Elasticsearch::Cxn::Factory::VERSION = '5.00';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
 has 'cxn_class'          => ( is => 'ro', required => 1 );
 has '_factory'           => ( is => 'ro', required => 1 );
-has 'default_host'       => ( is => 'ro', required => 1 );
+has 'default_host'       => ( is => 'ro', default  => 'http://localhost:9200' );
 has 'max_content_length' => ( is => 'rw', default  => 104_857_600 );
 
 #===================================
@@ -26,9 +26,8 @@ sub BUILDARGS {
             max_content_length => $self->max_content_length
         );
     };
-    $params->{default_host} = $cxn_class->default_host;
-    $params->{cxn_args}     = \%args;
-    $params->{cxn_class}    = $cxn_class;
+    $params->{cxn_args}  = \%args;
+    $params->{cxn_class} = $cxn_class;
     return $params;
 }
 
@@ -48,7 +47,7 @@ Search::Elasticsearch::Cxn::Factory - Used by CxnPools to create new Cxn instanc
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
