@@ -1,9 +1,7 @@
 package Search::Elasticsearch::Cxn::LWP;
-$Search::Elasticsearch::Cxn::LWP::VERSION = '2.03';
+$Search::Elasticsearch::Cxn::LWP::VERSION = '5.00';
 use Moo;
-with 'Search::Elasticsearch::Role::Cxn::HTTP',
-    'Search::Elasticsearch::Role::Cxn',
-    'Search::Elasticsearch::Role::Is_Sync';
+with 'Search::Elasticsearch::Role::Cxn', 'Search::Elasticsearch::Role::Is_Sync';
 
 use LWP::UserAgent();
 use HTTP::Headers();
@@ -24,11 +22,16 @@ sub perform_request {
     my $uri    = $self->build_uri($params);
     my $method = $params->{method};
 
+    my %headers;
+    if ( $params->{data} ) {
+        $headers{'Content-Type'}     = $params->{mime_type};
+        $headers{'Content-Encoding'} = $params->{encoding}
+            if $params->{encoding};
+    }
+
     my $request = HTTP::Request->new(
         $method => $uri,
-        [   'Content-Type' => $params->{mime_type},
-            %{ $self->default_headers },
-        ],
+        [ %headers, %{ $self->default_headers }, ],
         $params->{data}
     );
 
@@ -94,37 +97,32 @@ Search::Elasticsearch::Cxn::LWP - A Cxn implementation which uses LWP
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
 Provides an HTTP Cxn class and based on L<LWP>.
 The LWP backend uses pure Perl and persistent connections.
 
-This class does L<Search::Elasticsearch::Role::Cxn::HTTP>, whose documentation
-provides more information, L<Search::Elasticsearch::Role::Cxn> and
-L<Search::Elasticsearch::Role::Is_Sync>.
+This class does L<Search::Elasticsearch::Role::Cxn>, whose documentation
+provides more information, and L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 CONFIGURATION
 
 =head2 Inherited configuration
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<node|Search::Elasticsearch::Role::Cxn::HTTP/"node">
-
-=item * L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length">
-
-=item * L<deflate|Search::Elasticsearch::Role::Cxn::HTTP/"deflate">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<node|Search::Elasticsearch::Role::Cxn/"node">
+
+=item * L<max_content_length|Search::Elasticsearch::Role::Cxn/"max_content_length">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"gzip">
+
+=item * L<deflate|Search::Elasticsearch::Role::Cxn/"deflate">
+
 =item * L<request_timeout|Search::Elasticsearch::Role::Cxn/"request_timeout">
 
 =item * L<ping_timeout|Search::Elasticsearch::Role::Cxn/"ping_timeout">
@@ -213,28 +211,22 @@ error if the request failed.
 
 =head2 Inherited methods
 
-From L<Search::Elasticsearch::Role::Cxn::HTTP>
-
-=over
-
-=item * L<scheme()|Search::Elasticsearch::Role::Cxn::HTTP/"scheme()">
-
-=item * L<is_https()|Search::Elasticsearch::Role::Cxn::HTTP/"is_https()">
-
-=item * L<userinfo()|Search::Elasticsearch::Role::Cxn::HTTP/"userinfo()">
-
-=item * L<default_headers()|Search::Elasticsearch::Role::Cxn::HTTP/"default_headers()">
-
-=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn::HTTP/"max_content_length()">
-
-=item * L<build_uri()|Search::Elasticsearch::Role::Cxn::HTTP/"build_uri()">
-
-=back
-
 From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
+=item * L<scheme()|Search::Elasticsearch::Role::Cxn/"scheme()">
+
+=item * L<is_https()|Search::Elasticsearch::Role::Cxn/"is_https()">
+
+=item * L<userinfo()|Search::Elasticsearch::Role::Cxn/"userinfo()">
+
+=item * L<default_headers()|Search::Elasticsearch::Role::Cxn/"default_headers()">
+
+=item * L<max_content_length()|Search::Elasticsearch::Role::Cxn/"max_content_length()">
+
+=item * L<build_uri()|Search::Elasticsearch::Role::Cxn/"build_uri()">
+
 =item * L<host()|Search::Elasticsearch::Role::Cxn/"host()">
 
 =item * L<port()|Search::Elasticsearch::Role::Cxn/"port()">
@@ -267,7 +259,7 @@ From L<Search::Elasticsearch::Role::Cxn>
 
 =over
 
-=item * L<Search::Elasticsearch::Role::Cxn::HTTP>
+=item * L<Search::Elasticsearch::Role::Cxn>
 
 =item * L<Search::Elasticsearch::Cxn::HTTPTiny>
 
