@@ -1,5 +1,5 @@
 package Search::Elasticsearch::CxnPool::Sniff;
-$Search::Elasticsearch::CxnPool::Sniff::VERSION = '2.03';
+$Search::Elasticsearch::CxnPool::Sniff::VERSION = '5.00';
 use Moo;
 with 'Search::Elasticsearch::Role::CxnPool::Sniff',
     'Search::Elasticsearch::Role::Is_Sync';
@@ -50,7 +50,7 @@ sub sniff {
         $self->sniff_cxn($cxn) and return;
     }
 
-    $self->logger->infof("No live nodes available. Trying seed nodes.");
+    $self->logger->info("No live nodes available. Trying seed nodes.");
     for my $seed ( @{ $self->seed_nodes } ) {
         my $cxn = $self->cxn_factory->new_cxn($seed);
         $self->sniff_cxn($cxn) and return;
@@ -62,7 +62,7 @@ sub sniff {
 sub sniff_cxn {
 #===================================
     my ( $self, $cxn ) = @_;
-    return $self->parse_sniff( $cxn->protocol, $cxn->sniff );
+    return $self->parse_sniff( $cxn->sniff );
 }
 
 1;
@@ -81,7 +81,7 @@ Search::Elasticsearch::CxnPool::Sniff - A CxnPool for connecting to a local clus
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,7 @@ cluster, they will be auto-discovered during a sniff.
 If all sniffed nodes fail, then it falls back to sniffing the original
 I<seed> nodes that you specified in C<new()>.
 
-For L<HTTP Cxn classes|Search::Elasticsearch::Role::Cxn::HTTP>, this module
+For L<HTTP Cxn classes|Search::Elasticsearch::Role::Cxn>, this module
 will also dynamically detect the C<max_content_length> which the nodes
 in the cluster will accept.
 
@@ -122,7 +122,7 @@ L<Search::Elasticsearch::Role::Is_Sync>.
 
 The list of nodes to use to discover the cluster.  Can accept a single node,
 multiple nodes, and defaults to C<localhost:9200> if no C<nodes> are
-specified. See L<Search::Elasticsearch::Role::Cxn::HTTP/node> for details of the node
+specified. See L<Search::Elasticsearch::Role::Cxn/node> for details of the node
 specification.
 
 =head2 See also
