@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '2.03';
+$Search::Elasticsearch::Error::VERSION = '5.00';
 our $DEBUG = 0;
 
 @Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
@@ -179,7 +179,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -240,13 +240,13 @@ is triggered by the C<409> HTTP status code.
 =item * C<Search::Elasticsearch::Error::ContentLength>
 
 The request body was longer than the
-L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/max_content_length>.
+L<max_content_length|Search::Elasticsearch::Role::Cxn/max_content_length>.
 
 =item * C<Search::Elasticsearch::Error::RequestTimeout>
 
 The request took longer than the specified C<timeout>.  Currently only
 applies to the
-L<cluster_health|Search::Elasticsearch::Client::2_0::Direct::Cluster/cluster_health()>
+L<cluster_health|Search::Elasticsearch::Client::5_0::Direct::Cluster/cluster_health()>
 request.
 
 =back
