@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::CxnPool::Sniff;
-$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '2.03';
+$Search::Elasticsearch::Role::CxnPool::Sniff::VERSION = '5.00';
 use Moo::Role;
 with 'Search::Elasticsearch::Role::CxnPool';
 requires 'next_cxn', 'sniff';
@@ -33,10 +33,8 @@ sub schedule_check {
 #===================================
 sub parse_sniff {
 #===================================
-    my $self     = shift;
-    my $protocol = shift;
-    my $nodes    = shift or return;
-
+    my $self = shift;
+    my $nodes = shift or return;
     my @live_nodes;
     my $max       = 0;
     my $sniff_max = $self->sniff_max_content_length;
@@ -44,16 +42,17 @@ sub parse_sniff {
     for my $node_id ( keys %$nodes ) {
         my $data = $nodes->{$node_id};
 
-        my $host = $self->_extract_host( $data->{ $protocol . "_address" } )
+        my $addr = $data->{http}{publish_address} || $data->{http_address};
+        my $host = $self->_extract_host($addr)
             or next;
 
         $host = $self->should_accept_node( $host, $node_id, $data )
             or next;
 
         push @live_nodes, $host;
-        next unless $sniff_max and $data->{$protocol};
+        next unless $sniff_max and $data->{http};
 
-        my $node_max = $data->{$protocol}{max_content_length_in_bytes} || 0;
+        my $node_max = $data->{http}{max_content_length_in_bytes} || 0;
         $max
             = $node_max == 0 ? $max
             : $max == 0      ? $node_max
@@ -78,7 +77,7 @@ sub _extract_host {
     my $self = shift;
     my $host = shift || return;
     $host =~ s{^inet\[(.+)\]$}{$1};
-    $host =~ s{^[^/]+/}{};
+    $host =~ s{^[^/]*/}{};
     return $host;
 }
 
@@ -98,7 +97,7 @@ Search::Elasticsearch::Role::CxnPool::Sniff - A CxnPool role for connecting to a
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 CONFIGURATION
 
@@ -110,7 +109,7 @@ have been added to the cluster.  Defaults to `300` seconds.
 =head2 C<sniff_max_content_length>
 
 Whether we should set the
-L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/max_content_length>
+L<max_content_length|Search::Elasticsearch::Role::Cxn/max_content_length>
 dynamically while sniffing. Defaults to true unless a fixed
 C<max_content_length> was specified.
 
@@ -129,7 +128,7 @@ Schedules a sniff before the next request is processed.
 Parses the response from a sniff request and extracts the hostname/ip
 of all listed nodes, filtered through L</should_accept_node()>. If any live
 nodes are found, they are passed to L<Search::Elasticsearch::Role::CxnPool/set_cxns()>.
-The L<max_content_length|Search::Elasticsearch::Role::Cxn::HTTP/max_content_length>
+The L<max_content_length|Search::Elasticsearch::Role::Cxn/max_content_length>
 is also detected if L</sniff_max_content_length> is true.
 
 =head2 C<should_accept_node()>
