@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Logger;
-$Search::Elasticsearch::Role::Logger::VERSION = '2.03';
+$Search::Elasticsearch::Role::Logger::VERSION = '5.00';
 use Moo::Role;
 
 use URI();
@@ -7,11 +7,14 @@ use Try::Tiny;
 use Search::Elasticsearch::Util qw(new_error);
 use namespace::clean;
 
-has 'serializer' => ( is => 'ro', required => 1 );
-has 'log_as'     => ( is => 'ro', default  => 'elasticsearch.event' );
-has 'trace_as'   => ( is => 'ro', default  => 'elasticsearch.trace' );
-has 'log_to'     => ( is => 'ro' );
-has 'trace_to'   => ( is => 'ro' );
+has 'serializer'   => ( is => 'ro', required => 1 );
+has 'log_as'       => ( is => 'ro', default  => 'elasticsearch.event' );
+has 'trace_as'     => ( is => 'ro', default  => 'elasticsearch.trace' );
+has 'deprecate_as' => ( is => 'ro', default  => 'elasticsearch.deprecation' );
+has 'log_to'       => ( is => 'ro' );
+has 'trace_to'     => ( is => 'ro' );
+has 'deprecate_to' => ( is => 'ro' );
+
 has 'trace_handle' => (
     is      => 'lazy',
     handles => [qw( trace tracef is_trace)]
@@ -29,6 +32,8 @@ has 'log_handle' => (
     ]
 );
 
+has 'deprecate_handle' => ( is => 'lazy' );
+
 #===================================
 sub throw_error {
 #===================================
@@ -123,6 +128,12 @@ sub trace_comment {
     $self->trace("$comment\n");
 }
 
+#===================================
+sub deprecation {
+#===================================
+    my $self = shift;
+    $self->deprecate_handle->warnf( "[DEPRECATION] %s. In request: %s", @_ );
+}
 1;
 
 # ABSTRACT: Provides common functionality to Logger implementations
@@ -139,7 +150,7 @@ Search::Elasticsearch::Role::Logger - Provides common functionality to Logger im
 
 =head1 VERSION
 
-version 2.03
+version 5.00
 
 =head1 DESCRIPTION
 
@@ -155,7 +166,7 @@ See L<Search::Elasticsearch::Logger::LogAny> for the default implementation.
 
 Parameters passed to C<log_to> are used by L<Search::Elasticsearch::Role::Logger>
 implementations to setup the L</log_handle()>.  See
-L<Search::Elasticsearch::Logger::LogAny/log_to> for details.
+L<Search::Elasticsearch::Logger::LogAny> for details.
 
 =head2 C<log_as>
 
@@ -167,7 +178,7 @@ category C<"elasticsearch.event">, which can be configured with C<log_as>.
 
 Parameters passed to C<trace_to> are used by L<Search::Elasticsearch::Role::Logger>
 implementations to setup the L</trace_handle()>. See
-L<Search::Elasticsearch::Logger::LogAny/trace_to> for details.
+L<Search::Elasticsearch::Logger::LogAny> for details.
 
 =head2 C<trace_as>
 
@@ -175,6 +186,18 @@ By default, trace output emitted by L</trace_request()>, L</trace_response()>,
 L</trace_error()> and L</trace_comment()> are logged under the category
 C<elasticsearch.trace>, which can be configured with C<trace_as>.
 
+=head2 C<deprecate_to>
+
+Parameters passed to C<deprecate_to> are used by L<Search::Elasticsearch::Role::Logger>
+implementations to setup the L</deprecate_handle()>.  See
+L<Search::Elasticsearch::Logger::LogAny> for details.
+
+=head2 C<deprecate_as>
+
+By default, events emitted by L</deprecation()> are logged to the
+L</deprecate_handle()> under the
+category C<"elasticsearch.deprecation">, which can be configured with C<deprecate_as>.
+
 =head1 METHODS
 
 =head2 C<log_handle()>
@@ -189,6 +212,10 @@ C<is_error()>, C<critical()>, C<criticalf()> and  C<is_critical()>.
 Returns an object which can handle the methods:
 C<trace()>, C<tracef()> and C<is_trace()>.
 
+=head2 C<deprecate_handle()>
+
+Returns an object which can handle the C<warnf()> method.
+
 =head2 C<trace_request()>
 
     $logger->trace_request($cxn,\%request);
@@ -217,6 +244,12 @@ object.
 
 Used to insert debugging comments into trace output.
 
+=head2 C<deprecation()>
+
+    $logger->deprecation($warning,$request)
+
+Issues a deprecation warning to the deprecation logger.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
